@@ -1,5 +1,5 @@
 package Mail::DMARC::PurePerl;
-our $VERSION = '1.20130906'; # VERSION
+our $VERSION = '1.20140208'; # VERSION
 use strict;
 use warnings;
 
@@ -421,11 +421,14 @@ sub get_from_dom {
         return;
     };
 
-    # Should I do something special with a From field with multiple addresses?
-    # Do what if the domains differ? This returns only the last.
+# TODO: the From header can contain multiple addresses and should be
+# parsed as described in RFC 2822. If From has multiple-addresses,
+# then parse and use the domain in the Sender header.
+
+    # This returns only the domain in the last email address.
     # Caller can pass in pre-parsed from_dom if this doesn't suit them.
     #
-    # I care only about the domain. This is way faster than RFC822 parsing
+    # I care only about the domain. This is way faster than RFC2822 parsing
 
     my ($from_dom) = ( split /@/, $header )[-1]; # grab everything after the @
     ($from_dom) = split /(\s+|>)/, $from_dom;    # remove trailing cruft
@@ -540,7 +543,7 @@ Mail::DMARC::PurePerl - Pure Perl implementation of DMARC
 
 =head1 VERSION
 
-version 1.20130906
+version 1.20140208
 
 =head1 METHODS
 
@@ -699,23 +702,9 @@ Davide Migliavacca <shari@cpan.org>
 
 =back
 
-=head1 CONTRIBUTORS
-
-=over 4
-
-=item *
-
-Benny Pedersen <me@junc.eu>
-
-=item *
-
-ColocateUSA.net <company@colocateusa.net>
-
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by ColocateUSA.com.
+This software is copyright (c) 2014 by ColocateUSA.com.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
